@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2009 Pedro Castro
+ * Copyright (C) 2006-2010 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,6 +48,7 @@ public class Base {
 	private static Config config = null;
 	private static Dialogs dialogs = null;
 	private static SpellLanguages spellLanguages = null;
+	private static Backup backup = null;
 	
 	private static Document document = null;
 	private static Uri videoUri = null;
@@ -102,6 +103,10 @@ public class Base {
 		get { return spellLanguages; }
 	}
 	
+	public static Backup Backup {
+		get { return backup; }	
+	}
+	
 	public static Document Document {
 		get { return document; }
 	}
@@ -270,11 +275,12 @@ public class Base {
 		config = new Config();
 		dialogs = new Dialogs();
 		spellLanguages = new SpellLanguages();
+		backup = new Backup();
 
 		/* Initialize the GUI */
 		ui = new MainUi(handlers, out glade);
 		clipboards.WatchPrimaryChanges = true;
-		Catalog.Init(ExecutionContext.TranslationDomain, ConfigureDefines.LocaleDir);
+		Catalog.Init(ExecutionContext.TranslationDomain, ExecutionContext.LocaleDir);
 		
 		EmitInitFinishedEvent();
 	}
