@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2009 Pedro Castro
+ * Copyright (C) 2006-2010 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -79,6 +79,9 @@ public class WidgetNames {
 	public const string VideoForward = "videoForward";
 	public const string VideoSeekTo = "videoSeekTo";
 	public const string VideoSeekToSelection = "videoSeekToSelection";
+	public const string VideoSelectNearestSubtitle = "videoSelectNearestSubtitle";
+	public const string VideoAutoSelectSubtitles = "videoAutoSelectSubtitles";
+	public const string VideoLoopSelectionPlayback = "videoLoopSelectionPlayback";
 	public const string VideoSetSubtitleStart = "videoSetSubtitleStart";
 	public const string VideoSetSubtitleEnd = "videoSetSubtitleEnd";
 	
@@ -114,6 +117,8 @@ public class WidgetNames {
 	public const string VideoSetSubtitleStartButtonImage = "videoSetSubtitleStartButtonImage";
 	public const string VideoSetSubtitleEndButton = "videoSetSubtitleEndButton";
 	public const string VideoSetSubtitleEndButtonImage = "videoSetSubtitleEndButtonImage";
+	public const string VideoSetSubtitleStartEndButton = "videoSetSubtitleStartEndButton";
+	public const string VideoSetSubtitleStartEndButtonImage = "videoSetSubtitleStartEndButtonImage";
 	public const string VideoFrame = "videoFrame";
 	public const string VideoPlaybackHBox = "videoPlaybackHBox";
 	public const string VideoSlider = "videoSlider";
